@@ -81,7 +81,7 @@ func TestSchema_Diff(t *testing.T) {
 		"--from", "file://testdata/sqlite",
 		"--to", openSQLite(t, ""),
 	)
-	require.EqualError(t, err, "--dev-url cannot be empty")
+	require.EqualError(t, err, "--dev-url cannot be empty. See: https://atlasgo.io/atlas-schema/sql#dev-database")
 
 	// Desired state from migration directory.
 	s, err = runCmd(
@@ -312,6 +312,33 @@ env "local" {
 			"PRAGMA foreign_keys = on;",
 		}, lines)
 	})
+
+	t.Run("FromConfig/DevURL", func(t *testing.T) {
+		var (
+			p    = t.TempDir()
+			cfg  = filepath.Join(p, "atlas.hcl")
+			from = filepath.Join(p, "schema1.sql")
+		)
+		err = os.WriteFile(cfg, []byte(`
+env "local" {
+  dev = "sqlite://dev?mode=memory&_fk=1"
+  exclude = ["posts"]
+}
+`), 0600)
+		require.NoError(t, err)
+		require.NoError(t, os.WriteFile(from, []byte(`CREATE TABLE users (id int);`), 0600))
+		cmd := schemaCmd()
+		cmd.AddCommand(schemaDiffCmd())
+		s, err := runCmd(
+			cmd, "diff",
+			"--from", "file://"+from,
+			"--to", openSQLite(t, "CREATE TABLE users (id int, name text); CREATE TABLE posts (id int);"),
+			"--config", "file://"+cfg,
+			"--env", "local",
+		)
+		require.NoError(t, err)
+		require.Equal(t, "-- Add column \"name\" to table: \"users\"\nALTER TABLE `users` ADD COLUMN `name` text NULL;\n", s)
+	})
 }
 
 func TestSchema_Apply(t *testing.T) {
@@ -760,6 +787,46 @@ func TestSchema_ApplySQL(t *testing.T) {
 		)
 		require.EqualError(t, err, "missing scheme. Did you mean file://testdata/sqlite?")
 	})
+	t.Run("TxMode", func(t *testing.T) {
+		db := openSQLite(t, "")
+		p := filepath.Join(t.TempDir(), "schema.hcl")
+		require.NoError(t, os.WriteFile(p, []byte(`schema "main" {}
+
+table "ok" {
+  schema = schema.main
+  column "id" {
+    type = int
+  }
+}
+
+table "bad" {
+  schema = schema.main
+  column "id" {
+    type = int
+    default = "invalid check"
+  }
+}`), 0600))
+		s, err := runCmd(
+			schemaApplyCmd(),
+			"-u", db,
+			"--to", "file://"+p,
+			"--auto-approve",
+		)
+		require.Error(t, err)
+		require.Equal(t, strings.Join([]string{
+			"-- Planned Changes:",
+			`-- Create "ok" table`,
+			"CREATE TABLE `ok` (`id` int NOT NULL);",
+			`-- Create "bad" table`,
+			"CREATE TABLE `bad` (`id` int NOT NULL DEFAULT invalid check);",
+			"Error: create \"bad\" table: near \")\": syntax error\n",
+		}, "\n"), s)
+
+		// The "ok" table should be created, as changes are rolled back on error.
+		s, err = runCmd(schemaInspectCmd(), "-u", db)
+		require.NoError(t, err)
+		require.Equal(t, "schema \"main\" {\n}\n", s)
+	})
 }
 
 func TestSchema_InspectLog(t *testing.T) {
@@ -775,6 +842,57 @@ func TestSchema_InspectLog(t *testing.T) {
 	require.Equal(t, `{"schemas":[{"name":"main","tables":[{"name":"t1","columns":[{"name":"id","type":"INTEGER","null":true}],"primary_key":{"parts":[{"column":"id"}]}},{"name":"t2","columns":[{"name":"name","type":"TEXT","null":true}]}]}]}`, s)
 }
 
+func TestSchema_InspectFile(t *testing.T) {
+	var (
+		p   = t.TempDir()
+		cp  = filepath.Join(p, "atlas.hcl")
+		sp  = filepath.Join(p, "schema.hcl")
+		cfg = fmt.Sprintf(`
+env "db" {
+  url = "%s"
+  dev = "docker://should-not-be-opened"
+}
+
+env "file" {
+  dev = "%s"
+}
+`, openSQLite(t, "create table t1(c int)"), openSQLite(t, ""))
+	)
+
+	require.NoError(t, os.WriteFile(cp, []byte(cfg), 0600))
+	require.NoError(t, os.WriteFile(sp, []byte(`
+schema "main" {}
+table "users" {
+  schema = schema.main
+  column "id" {
+    type = int
+  }
+}
+`), 0600))
+	cmd := schemaCmd()
+	cmd.AddCommand(schemaInspectCmd())
+	s, err := runCmd(
+		cmd, "inspect",
+		"-c", "file://"+cp,
+		"--env", "db",
+		"--format", "{{ sql . }}",
+	)
+	require.NoError(t, err)
+	require.Equal(t, "-- Create \"t1\" table\nCREATE TABLE `t1` (`c` int NULL);\n", s)
+
+	cmd = schemaCmd()
+	cmd.AddCommand(schemaInspectCmd())
+	s, err = runCmd(
+		cmd, "inspect",
+		"-c", "file://"+cp,
+		"--env", "file",
+		"--url", "file://"+sp,
+		"--format", "{{ sql . }}",
+	)
+	require.NoError(t, err)
+	require.Equal(t, "-- Create \"users\" table\nCREATE TABLE `users` (`id` int NOT NULL);\n", s)
+}
+
 func TestFmt(t *testing.T) {
 	for _, tt := range []struct {
 		name          string
