@@ -2,8 +2,8 @@
 // This source code is licensed under the Apache 2.0 license found
 // in the LICENSE file in the root directory of this source tree.
 
-// Package cmdext provides extensions to the Atlas CLI that
-// may be moved to a separate repository in the future.
+// Package cmdext provides extensions to the Atlas configuration
+// file such as schema loaders, data sources and cloud connectors.
 package cmdext
 
 import (
@@ -15,6 +15,8 @@ import (
 	"io/fs"
 	"net/url"
 	"os"
+	"os/exec"
+	"path"
 	"path/filepath"
 	"reflect"
 	"strconv"
@@ -27,6 +29,7 @@ import (
 	"ariga.io/atlas/sql/schema"
 	"ariga.io/atlas/sql/sqlclient"
 	"ariga.io/atlas/sql/sqltool"
+	"github.com/zclconf/go-cty/cty/gocty"
 
 	"entgo.io/ent/dialect/sql"
 	entschema "entgo.io/ent/dialect/sql/schema"
@@ -46,13 +49,15 @@ import (
 
 // DataSources exposes the data sources provided by this package.
 var DataSources = []schemahcl.Option{
-	schemahcl.WithDataSource("sql", QuerySrc),
-	schemahcl.WithDataSource("runtimevar", RuntimeVarSrc),
+	schemahcl.WithDataSource("sql", Query),
+	schemahcl.WithDataSource("runtimevar", RuntimeVar),
 	schemahcl.WithDataSource("template_dir", TemplateDir),
 	schemahcl.WithDataSource("remote_dir", RemoteDir),
+	schemahcl.WithDataSource("hcl_schema", SchemaHCL),
+	schemahcl.WithDataSource("external_schema", SchemaExternal),
 }
 
-// RuntimeVarSrc exposes the gocloud.dev/runtimevar as a schemahcl datasource.
+// RuntimeVar exposes the gocloud.dev/runtimevar as a schemahcl datasource.
 //
 //	data "runtimevar" "pass" {
 //	  url = "driver://path?query=param"
@@ -61,7 +66,7 @@ var DataSources = []schemahcl.Option{
 //	locals {
 //	  url = "mysql://root:${data.runtimevar.pass}@:3306/"
 //	}
-func RuntimeVarSrc(c *hcl.EvalContext, block *hclsyntax.Block) (cty.Value, error) {
+func RuntimeVar(c *hcl.EvalContext, block *hclsyntax.Block) (cty.Value, error) {
 	var (
 		args struct {
 			URL string `hcl:"url"`
@@ -108,7 +113,7 @@ func RuntimeVarSrc(c *hcl.EvalContext, block *hclsyntax.Block) (cty.Value, error
 	return cty.StringVal(sv), nil
 }
 
-// QuerySrc exposes the database/sql.Query as a schemahcl datasource.
+// Query exposes the database/sql.Query as a schemahcl datasource.
 //
 //	data "sql" "tenants" {
 //	  url = var.url
@@ -120,7 +125,7 @@ func RuntimeVarSrc(c *hcl.EvalContext, block *hclsyntax.Block) (cty.Value, error
 //	  for_each = toset(data.sql.tenants.values)
 //	  url      = urlsetpath(var.url, each.value)
 //	}
-func QuerySrc(ctx *hcl.EvalContext, block *hclsyntax.Block) (cty.Value, error) {
+func Query(ctx *hcl.EvalContext, block *hclsyntax.Block) (cty.Value, error) {
 	var (
 		args struct {
 			URL    string   `hcl:"url"`
@@ -255,8 +260,26 @@ func TemplateDir(ctx *hcl.EvalContext, block *hclsyntax.Block) (cty.Value, error
 					vars[k.AsString()] = f
 				case cty.Bool:
 					vars[k.AsString()] = v.True()
+				case cty.List(cty.String):
+					var s []string
+					if err := gocty.FromCtyValue(v, &s); err != nil {
+						return cty.NilVal, errorf("convert strings: %w", err)
+					}
+					vars[k.AsString()] = s
+				case cty.List(cty.Number):
+					var s []float64
+					if err := gocty.FromCtyValue(v, &s); err != nil {
+						return cty.NilVal, errorf("convert floats: %w", err)
+					}
+					vars[k.AsString()] = s
+				case cty.List(cty.Bool):
+					var s []bool
+					if err := gocty.FromCtyValue(v, &s); err != nil {
+						return cty.NilVal, errorf("convert bools: %w", err)
+					}
+					vars[k.AsString()] = s
 				default:
-					return cty.NilVal, errorf(`attribute "vars" must be a map of strings, numbers or booleans, got: %s`, v.Type())
+					return cty.NilVal, errorf(`attribute "vars" must be a map of strings, numbers or booleans, got: %s`, v.Type().FriendlyName())
 				}
 			}
 		}
@@ -265,7 +288,14 @@ func TemplateDir(ctx *hcl.EvalContext, block *hclsyntax.Block) (cty.Value, error
 	if len(attrs) > 0 {
 		return cty.NilVal, errorf("unexpected attributes: %v", attrs)
 	}
-	t := template.New("template_dir")
+	dirname := path.Join(args.Path, block.Labels[1])
+	dir := migrate.OpenMemDir(dirname)
+	// Clear existing directories in case the config was called
+	// multiple times with different variables.
+	if files, err := dir.Files(); err != nil || len(files) > 0 {
+		dir.Reset()
+	}
+	t := template.New("template_dir").Option("missingkey=error")
 	err := filepath.Walk(args.Path, func(path string, d os.FileInfo, err error) error {
 		if err != nil {
 			return fmt.Errorf("walk path %s: %w", path, err)
@@ -278,7 +308,6 @@ func TemplateDir(ctx *hcl.EvalContext, block *hclsyntax.Block) (cty.Value, error
 	if err != nil {
 		return cty.NilVal, errorf(err.Error())
 	}
-	dir := migrate.OpenMemDir(args.Path)
 	// Only top-level (template) files are treated as migrations.
 	matches, err := fs.Glob(os.DirFS(args.Path), "*.sql")
 	if err != nil {
@@ -287,7 +316,7 @@ func TemplateDir(ctx *hcl.EvalContext, block *hclsyntax.Block) (cty.Value, error
 	for _, m := range matches {
 		var b bytes.Buffer
 		if err := t.ExecuteTemplate(&b, m, vars); err != nil {
-			return cty.NilVal, errorf("executing template %q: %w", m, err)
+			return cty.NilVal, errorf("executing template: %w", err)
 		}
 		if err := dir.WriteFile(m, b.Bytes()); err != nil {
 			return cty.NilVal, errorf("writing file %q: %w", m, err)
@@ -297,15 +326,29 @@ func TemplateDir(ctx *hcl.EvalContext, block *hclsyntax.Block) (cty.Value, error
 	if err != nil {
 		return cty.NilVal, err
 	}
-	b, err := sum.MarshalText()
-	if err != nil {
-		return cty.NilVal, err
-	}
-	if err := dir.WriteFile(migrate.HashFileName, b); err != nil {
+	if err := migrate.WriteSumFile(dir, sum); err != nil {
 		return cty.NilVal, err
 	}
+	// Sync template dir to local filesystem.
+	dir.SyncWrites(func(name string, data []byte) error {
+		if name == migrate.HashFileName {
+			return nil
+		}
+		l, err := migrate.NewLocalDir(args.Path)
+		if err != nil {
+			return err
+		}
+		if err := l.WriteFile(name, data); err != nil {
+			return err
+		}
+		sum, err := l.Checksum()
+		if err != nil {
+			return err
+		}
+		return migrate.WriteSumFile(l, sum)
+	})
 	return cty.ObjectVal(map[string]cty.Value{
-		"url": cty.StringVal(fmt.Sprintf("mem://%s", args.Path)),
+		"url": cty.StringVal(fmt.Sprintf("mem://%s", dirname)),
 	}), nil
 }
 
@@ -402,6 +445,95 @@ func RemoteDir(ctx *hcl.EvalContext, block *hclsyntax.Block) (cty.Value, error)
 	}), nil
 }
 
+// SchemaHCL is a data source that reads an Atlas HCL schema file(s), evaluates it
+// with the given variables and exposes its resulting schema as in-memory HCL file.
+func SchemaHCL(ctx *hcl.EvalContext, block *hclsyntax.Block) (cty.Value, error) {
+	var (
+		args struct {
+			Path   string               `hcl:"path"`
+			Vars   map[string]cty.Value `hcl:"vars,optional"`
+			Remain hcl.Body             `hcl:",remain"`
+		}
+		errorf = blockError("data.hcl_schema", block)
+	)
+	if diags := gohcl.DecodeBody(block.Body, ctx, &args); diags.HasErrors() {
+		return cty.NilVal, errorf("decoding body: %v", diags)
+	}
+	attrs, diags := args.Remain.JustAttributes()
+	if diags.HasErrors() {
+		return cty.NilVal, errorf("getting attributes: %v", diags)
+	}
+	if len(attrs) > 0 {
+		return cty.NilVal, errorf("unexpected attributes: %v", attrs)
+	}
+	if args.Path == "" {
+		return cty.NilVal, errorf("path cannot be empty")
+	}
+	u, err := url.JoinPath("mem://hcl_schema", block.Labels[1])
+	if err != nil {
+		return cty.NilVal, errorf("build url: %v", err)
+	}
+	memLoader.states[u] = StateLoaderFunc(func(ctx context.Context, config *StateReaderConfig) (*StateReadCloser, error) {
+		cfg := *config
+		cfg.Vars = args.Vars
+		return stateReaderHCL(ctx, &cfg, []string{args.Path})
+	})
+	return cty.ObjectVal(map[string]cty.Value{
+		"url": cty.StringVal(u),
+	}), nil
+}
+
+// SchemaExternal is a data source that reads a SQL schema state from external program.
+func SchemaExternal(ctx *hcl.EvalContext, block *hclsyntax.Block) (cty.Value, error) {
+	var (
+		args struct {
+			Program []string `hcl:"program"`
+			Dir     string   `hcl:"working_dir,optional"`
+			Remain  hcl.Body `hcl:",remain"`
+		}
+		errorf = blockError("data.external_schema", block)
+	)
+	if diags := gohcl.DecodeBody(block.Body, ctx, &args); diags.HasErrors() {
+		return cty.NilVal, errorf("decoding body: %v", diags)
+	}
+	attrs, diags := args.Remain.JustAttributes()
+	if diags.HasErrors() {
+		return cty.NilVal, errorf("getting attributes: %v", diags)
+	}
+	if len(attrs) > 0 {
+		return cty.NilVal, errorf("unexpected attributes: %v", attrs)
+	}
+	if len(args.Program) == 0 {
+		return cty.NilVal, errorf("program cannot be empty")
+	}
+	cmd := exec.Command(args.Program[0], args.Program[1:]...)
+	if args.Dir != "" {
+		cmd.Dir = args.Dir
+	}
+	out, err := cmd.Output()
+	if err != nil {
+		msg := err.Error()
+		if ee, ok := err.(*exec.ExitError); ok && len(ee.Stderr) > 0 {
+			msg = string(ee.Stderr)
+		}
+		return cty.NilVal, errorf("running program %v: %v", cmd.Path, msg)
+	}
+	dir, err := fileAsDir("schema.sql", out)
+	if err != nil {
+		return cty.NilVal, errorf("converting output to migration: %v", err)
+	}
+	u, err := url.JoinPath("mem://external_schema", block.Labels[1])
+	if err != nil {
+		return cty.NilVal, errorf("build url: %v", err)
+	}
+	memLoader.states[u] = StateLoaderFunc(func(ctx context.Context, config *StateReaderConfig) (*StateReadCloser, error) {
+		return stateReaderSQL(ctx, config, dir)
+	})
+	return cty.ObjectVal(map[string]cty.Value{
+		"url": cty.StringVal(u),
+	}), nil
+}
+
 func memdir(client *cloudapi.Client, dirName string, tag string) (string, error) {
 	input := cloudapi.DirInput{
 		Name: dirName,
@@ -440,15 +572,13 @@ func blockError(name string, b *hclsyntax.Block) func(string, ...any) error {
 }
 
 type (
-	// LoadStateOptions for external state loaders.
-	LoadStateOptions struct {
-		URLs []*url.URL
-		Dev  *sqlclient.Client // Client for the dev database.
-	}
 	// StateLoader allows loading StateReader's from external sources.
 	StateLoader interface {
-		LoadState(context.Context, *LoadStateOptions) (migrate.StateReader, error)
+		LoadState(context.Context, *StateReaderConfig) (*StateReadCloser, error)
 	}
+	// The StateLoaderFunc type is an adapter to allow the use of ordinary
+	// function as StateLoader.
+	StateLoaderFunc func(context.Context, *StateReaderConfig) (*StateReadCloser, error)
 
 	// MigrateDiffOptions for external migration differ.
 	MigrateDiffOptions struct {
@@ -466,16 +596,29 @@ type (
 	}
 )
 
+// LoadState calls f(ctx, opts).
+func (f StateLoaderFunc) LoadState(ctx context.Context, opts *StateReaderConfig) (*StateReadCloser, error) {
+	return f(ctx, opts)
+}
+
 var (
 	// States is a global registry for external state loaders.
 	States = registry{
 		"ent": EntLoader{},
+		"mem": memLoader,
 	}
+	memLoader       = MemLoader{states: make(map[string]StateLoader)}
 	errNotSchemaURL = errors.New("missing schema in --dev-url. See: https://atlasgo.io/url")
 )
 
 type registry map[string]StateLoader
 
+// HasLoader returns true if the given scheme is registered.
+func (r registry) HasLoader(scheme string) bool {
+	_, ok := r[scheme]
+	return ok
+}
+
 // Loader returns the state loader for the given scheme.
 func (r registry) Loader(scheme string) (StateLoader, bool) {
 	l, ok := r[scheme]
@@ -492,26 +635,44 @@ func (r registry) Differ(to []string) (MigrateDiffer, bool) {
 	return nil, false
 }
 
+// MemLoader is a StateLoader for loading data-sources
+// that were loaded into program memory.
+type MemLoader struct {
+	states map[string]StateLoader
+}
+
+// LoadState loads the state loaded from data-sources into memory.
+func (l MemLoader) LoadState(ctx context.Context, config *StateReaderConfig) (*StateReadCloser, error) {
+	if len(config.URLs) != 1 {
+		return nil, errors.New(`"mem://" requires exactly one data-source URL`)
+	}
+	u := config.URLs[0].String()
+	if l.states[u] == nil {
+		return nil, fmt.Errorf("data-source state %q not found in memory", u)
+	}
+	return l.states[u].LoadState(ctx, config)
+}
+
 // EntLoader is a StateLoader for loading ent.Schema's as StateReader's.
 type EntLoader struct{}
 
 // LoadState returns a migrate.StateReader that reads the schema from an ent.Schema.
-func (l EntLoader) LoadState(ctx context.Context, opts *LoadStateOptions) (migrate.StateReader, error) {
+func (l EntLoader) LoadState(ctx context.Context, config *StateReaderConfig) (*StateReadCloser, error) {
 	switch {
-	case len(opts.URLs) != 1:
+	case len(config.URLs) != 1:
 		return nil, errors.New(`"ent://" requires exactly one schema URL`)
-	case opts.Dev == nil:
+	case config.Dev == nil:
 		return nil, errors.New(`required flag "--dev-url" not set`)
-	case opts.Dev.URL.Schema == "":
+	case config.Dev.URL.Schema == "":
 		return nil, errNotSchemaURL
-	case opts.URLs[0].Query().Has("globalid"):
+	case config.URLs[0].Query().Has("globalid"):
 		return nil, errors.New("globalid is not supported by this command. Use 'migrate diff' instead")
 	}
-	tables, err := l.tables(opts.URLs[0])
+	tables, err := l.tables(config.URLs[0])
 	if err != nil {
 		return nil, err
 	}
-	m, err := entschema.NewMigrate(sql.OpenDB(opts.Dev.Name, opts.Dev.DB))
+	m, err := entschema.NewMigrate(sql.OpenDB(config.Dev.Name, config.Dev.DB))
 	if err != nil {
 		return nil, fmt.Errorf("creating migrate reader: %w", err)
 	}
@@ -519,22 +680,26 @@ func (l EntLoader) LoadState(ctx context.Context, opts *LoadStateOptions) (migra
 	if err != nil {
 		return nil, fmt.Errorf("reading schema state: %w", err)
 	}
-	if nr, ok := opts.Dev.Driver.(schema.Normalizer); ok {
-		if realm, err = nr.NormalizeRealm(ctx, realm); err != nil {
-			return nil, err
-		}
-	}
 	if len(realm.Schemas) != 1 {
 		return nil, fmt.Errorf("expect exactly one schema, got %d", len(realm.Schemas))
 	}
+	if nr, ok := config.Dev.Driver.(schema.Normalizer); ok {
+		if realm.Schemas[0], err = nr.NormalizeSchema(ctx, realm.Schemas[0]); err != nil {
+			return nil, err
+		}
+	}
 	// Use the dev-database schema name if the schema name is empty.
-	if realm.Schemas[0].Name == "" && opts.Dev.URL.Schema != "" {
-		realm.Schemas[0].Name = opts.Dev.URL.Schema
+	if realm.Schemas[0].Name == "" && config.Dev.URL.Schema != "" {
+		realm.Schemas[0].Name = config.Dev.URL.Schema
 	}
 	for _, t := range realm.Schemas[0].Tables {
 		t.Schema = realm.Schemas[0]
 	}
-	return migrate.Realm(realm), nil
+	rc := &StateReadCloser{StateReader: migrate.Realm(realm)}
+	if config.Dev != nil && config.Dev.URL.Schema != "" {
+		rc.Schema = config.Dev.URL.Schema
+	}
+	return rc, nil
 }
 
 // MigrateDiff returns the diff between ent.Schema and a directory.
