@@ -110,7 +110,7 @@ func TestEntLoader_LoadState(t *testing.T) {
 	require.NoError(t, err)
 	l, ok := cmdext.States.Loader("ent")
 	require.True(t, ok)
-	state, err := l.LoadState(ctx, &cmdext.LoadStateOptions{
+	state, err := l.LoadState(ctx, &cmdext.StateReaderConfig{
 		Dev:  drv,
 		URLs: []*url.URL{u},
 	})
@@ -228,6 +228,142 @@ dir = data.template_dir.tenant.url
 	require.Equal(t, "create table a8m.t(c int);", string(files[0].Bytes()))
 }
 
+func TestSchemaHCL(t *testing.T) {
+	var (
+		v struct {
+			Schema string `spec:"schema"`
+		}
+		dir   = t.TempDir()
+		ctx   = context.Background()
+		state = schemahcl.New(cmdext.DataSources...)
+	)
+	err := os.WriteFile(filepath.Join(dir, "schema.hcl"), []byte(`
+variable "schema" {
+  type = string
+}
+
+schema "dynamic" {
+  name = var.schema
+}
+
+table "t" {
+  schema = schema.dynamic
+  column "c" {
+    type = int
+  }
+}
+`), 0644)
+	require.NoError(t, err)
+	err = state.EvalBytes([]byte(`
+variable "path" {
+  type = string
+}
+
+data "hcl_schema" "a8m" {
+  path = var.path
+  vars = {
+    schema = "a8m"
+  }
+}
+
+schema = data.hcl_schema.a8m.url
+`), &v, map[string]cty.Value{
+		"path": cty.StringVal(dir),
+	})
+	require.NoError(t, err)
+	require.NotEmpty(t, v.Schema)
+	u, err := url.Parse(v.Schema)
+	require.NoError(t, err)
+	loader, ok := cmdext.States.Loader(u.Scheme)
+	require.True(t, ok)
+	drv, err := sqlclient.Open(ctx, "sqlite://test?mode=memory&_fk=1")
+	require.NoError(t, err)
+	sr, err := loader.LoadState(ctx, &cmdext.StateReaderConfig{
+		Dev:  drv,
+		URLs: []*url.URL{u},
+		// Variables are not needed at this stage,
+		// as they are defined on the data source.
+	})
+	require.NoError(t, err)
+	realm, err := sr.ReadState(ctx)
+	require.NoError(t, err)
+	buf, err := drv.MarshalSpec(realm)
+	require.NoError(t, err)
+	require.Equal(t, `table "t" {
+  schema = schema.a8m
+  column "c" {
+    null = false
+    type = int
+  }
+}
+schema "a8m" {
+}
+`, string(buf))
+
+	// An empty schema case.
+	err = os.WriteFile(filepath.Join(dir, "schema.hcl"), []byte(``), 0644)
+	require.NoError(t, err)
+	sr, err = loader.LoadState(ctx, &cmdext.StateReaderConfig{
+		Dev:  drv,
+		URLs: []*url.URL{u},
+		// Variables are not needed at this stage,
+		// as they are defined on the data source.
+	})
+	require.NoError(t, err)
+	realm, err = sr.ReadState(ctx)
+	require.NoError(t, err)
+	buf, err = drv.MarshalSpec(realm)
+	require.NoError(t, err)
+	require.Equal(t, ``, string(buf))
+}
+
+func TestExternalSchema(t *testing.T) {
+	var (
+		v struct {
+			Schema string `spec:"schema"`
+		}
+		ctx   = context.Background()
+		state = schemahcl.New(cmdext.DataSources...)
+	)
+	err := state.EvalBytes([]byte(`
+data "external_schema" "a8m" {
+  program = [
+    "echo",
+    "CREATE TABLE t(c int);",
+  ]
+}
+
+schema = data.external_schema.a8m.url
+`), &v, nil)
+	require.NoError(t, err)
+	require.NotEmpty(t, v.Schema)
+	u, err := url.Parse(v.Schema)
+	require.NoError(t, err)
+	loader, ok := cmdext.States.Loader(u.Scheme)
+	require.True(t, ok)
+	drv, err := sqlclient.Open(ctx, "sqlite://test?mode=memory&_fk=1")
+	require.NoError(t, err)
+	sr, err := loader.LoadState(ctx, &cmdext.StateReaderConfig{
+		Dev:  drv,
+		URLs: []*url.URL{u},
+	})
+	require.NoError(t, err)
+	realm, err := sr.ReadState(ctx)
+	require.NoError(t, err)
+	buf, err := drv.MarshalSpec(realm)
+	require.NoError(t, err)
+	require.Equal(t, `table "t" {
+  schema = schema.main
+  column "c" {
+    null = true
+    type = int
+  }
+}
+schema "main" {
+}
+`, string(buf))
+}
+
 func TestAtlasConfig(t *testing.T) {
 	var (
 		v struct {
@@ -320,6 +456,8 @@ func TestRemoteDir(t *testing.T) {
 data "remote_dir" "hello" {
   name  = "atlas"
 }
+
+dir = data.remote_dir.hello.url
 `), &v, map[string]cty.Value{"cloud_url": cty.StringVal(srv.URL)})
 	require.EqualError(t, err, "data.remote_dir.hello: missing atlas cloud config")
 
