@@ -10,6 +10,7 @@ import (
 	"errors"
 	"fmt"
 	"io"
+	"io/fs"
 	"strings"
 	"text/template"
 
@@ -86,7 +87,10 @@ func (r *Runner) summary(ctx context.Context) error {
 		r.sum.Files = append(r.sum.Files, &FileReport{Name: migrate.HashFileName, Error: err.Error()})
 		return r.sum.StepError(stepIntegrityCheck, fmt.Sprintf("File %s is invalid", migrate.HashFileName), err)
 	default:
-		r.sum.StepResult(stepIntegrityCheck, fmt.Sprintf("File %s is valid", migrate.HashFileName), nil)
+		// If the hash file exists, it is valid.
+		if _, err := fs.Stat(r.Dir, migrate.HashFileName); err == nil {
+			r.sum.StepResult(stepIntegrityCheck, fmt.Sprintf("File %s is valid", migrate.HashFileName), nil)
+		}
 	}
 
 	// Detect new migration files.
@@ -115,12 +119,18 @@ func (r *Runner) summary(ctx context.Context) error {
 			nl = nolintRules(f)
 			fr = NewFileReport(f)
 		)
+		if nl.ignored {
+			continue
+		}
 		for _, az := range r.Analyzers {
-			if err := az.Analyze(ctx, &sqlcheck.Pass{
+			err := az.Analyze(ctx, &sqlcheck.Pass{
 				File:     f,
 				Dev:      r.Dev,
 				Reporter: nl.reporterFor(fr, az),
-			}); err != nil && !nl.skipped {
+			})
+			// If the last report was skipped,
+			// skip emitting its error.
+			if err != nil && !nl.skipped {
 				es = append(es, err.Error())
 			}
 		}
@@ -194,10 +204,10 @@ type (
 
 		// Steps of the analysis. Added in verbose mode.
 		Steps []struct {
-			Name   string `json:"Name,omitempty"`   // Step name.
-			Text   string `json:"Text,omitempty"`   // Step description.
-			Error  string `json:"Error,omitempty"`  // Error that cause the execution to halt.
-			Result any    `json:"Result,omitempty"` // Result of the step. For example, a diagnostic.
+			Name   string      `json:"Name,omitempty"`   // Step name.
+			Text   string      `json:"Text,omitempty"`   // Step description.
+			Error  string      `json:"Error,omitempty"`  // Error that cause the execution to halt.
+			Result *FileReport `json:"Result,omitempty"` // Result of the step. For example, a diagnostic.
 		}
 
 		// Schema versions found by the runner.
@@ -254,12 +264,12 @@ func NewSummaryReport(c *sqlclient.Client, dir migrate.Dir) *SummaryReport {
 }
 
 // StepResult appends step result to the summary.
-func (f *SummaryReport) StepResult(name, text string, result any) {
+func (f *SummaryReport) StepResult(name, text string, result *FileReport) {
 	f.Steps = append(f.Steps, struct {
-		Name   string `json:"Name,omitempty"`
-		Text   string `json:"Text,omitempty"`
-		Error  string `json:"Error,omitempty"`
-		Result any    `json:"Result,omitempty"`
+		Name   string      `json:"Name,omitempty"`
+		Text   string      `json:"Text,omitempty"`
+		Error  string      `json:"Error,omitempty"`
+		Result *FileReport `json:"Result,omitempty"`
 	}{
 		Name:   name,
 		Text:   text,
@@ -270,10 +280,10 @@ func (f *SummaryReport) StepResult(name, text string, result any) {
 // StepError appends step error to the summary.
 func (f *SummaryReport) StepError(name, text string, err error) error {
 	f.Steps = append(f.Steps, struct {
-		Name   string `json:"Name,omitempty"`
-		Text   string `json:"Text,omitempty"`
-		Error  string `json:"Error,omitempty"`
-		Result any    `json:"Result,omitempty"`
+		Name   string      `json:"Name,omitempty"`
+		Text   string      `json:"Text,omitempty"`
+		Error  string      `json:"Error,omitempty"`
+		Result *FileReport `json:"Result,omitempty"`
 	}{
 		Name:  name,
 		Text:  text,
@@ -314,6 +324,21 @@ func (w *TemplateWriter) WriteReport(r *SummaryReport) error {
 
 func nolintRules(f *sqlcheck.File) *skipRules {
 	s := &skipRules{pos2rules: make(map[int][]string)}
+	if l, ok := f.File.(*migrate.LocalFile); ok {
+		ds := l.Directive("nolint")
+		// A file directive without specific classes/codes
+		// (e.g. atlas:nolint) ignores the entire file.
+		if s.ignored = len(ds) == 1 && ds[0] == ""; s.ignored {
+			return s
+		}
+		// A file directive with specific classes/codes applies these
+		// rules on all statements (e.g., atlas:nolint destructive).
+		for _, d := range ds {
+			for _, c := range f.Changes {
+				s.pos2rules[c.Stmt.Pos] = append(s.pos2rules[c.Stmt.Pos], strings.Split(d, " ")...)
+			}
+		}
+	}
 	for _, c := range f.Changes {
 		for _, d := range c.Stmt.Directive("nolint") {
 			s.pos2rules[c.Stmt.Pos] = append(s.pos2rules[c.Stmt.Pos], strings.Split(d, " ")...)
@@ -324,7 +349,8 @@ func nolintRules(f *sqlcheck.File) *skipRules {
 
 type skipRules struct {
 	pos2rules map[int][]string // statement positions to rules
-	skipped   bool             // last one skipped
+	ignored   bool             // file is ignored. i.e., no analysis is performed
+	skipped   bool             // if the last report was skipped by the rules
 }
 
 func (s *skipRules) reporterFor(rw sqlcheck.ReportWriter, az sqlcheck.Analyzer) sqlcheck.ReportWriter {
