@@ -20,33 +20,48 @@ func VarAttr(k, v string) *schemahcl.Attr {
 	return schemahcl.RefAttr(k, &schemahcl.Ref{V: v})
 }
 
-type doc struct {
-	Tables  []*sqlspec.Table  `spec:"table"`
-	Schemas []*sqlspec.Schema `spec:"schema"`
-}
+type (
+	// SchemaSpec is returned by driver convert functions to
+	// marshal a *schema.Schema into top-level spec objects.
+	SchemaSpec struct {
+		Schema *sqlspec.Schema
+		Tables []*sqlspec.Table
+		Views  []*sqlspec.View
+	}
+	doc struct {
+		Tables  []*sqlspec.Table  `spec:"table"`
+		Views   []*sqlspec.View   `spec:"view"`
+		Schemas []*sqlspec.Schema `spec:"schema"`
+	}
+)
 
 // Marshal marshals v into an Atlas DDL document using a schemahcl.Marshaler. Marshal uses the given
-// schemaSpec function to convert a *schema.Schema into *sqlspec.Schema and []*sqlspec.Table.
-func Marshal(v any, marshaler schemahcl.Marshaler, schemaSpec func(schem *schema.Schema) (*sqlspec.Schema, []*sqlspec.Table, error)) ([]byte, error) {
+// schemaSpec function to convert a *schema.Schema into *sqlspec.Schema, []*sqlspec.Table and []*sqlspec.View.
+func Marshal(v any, marshaler schemahcl.Marshaler, convertFunc func(*schema.Schema) (*SchemaSpec, error)) ([]byte, error) {
 	d := &doc{}
 	switch s := v.(type) {
 	case *schema.Schema:
-		spec, tables, err := schemaSpec(s)
+		spec, err := convertFunc(s)
 		if err != nil {
 			return nil, fmt.Errorf("specutil: failed converting schema to spec: %w", err)
 		}
-		d.Tables = tables
-		d.Schemas = []*sqlspec.Schema{spec}
+		d.Tables = spec.Tables
+		d.Views = spec.Views
+		d.Schemas = []*sqlspec.Schema{spec.Schema}
 	case *schema.Realm:
 		for _, s := range s.Schemas {
-			spec, tables, err := schemaSpec(s)
+			spec, err := convertFunc(s)
 			if err != nil {
 				return nil, fmt.Errorf("specutil: failed converting schema to spec: %w", err)
 			}
-			d.Tables = append(d.Tables, tables...)
-			d.Schemas = append(d.Schemas, spec)
+			d.Tables = append(d.Tables, spec.Tables...)
+			d.Views = append(d.Views, spec.Views...)
+			d.Schemas = append(d.Schemas, spec.Schema)
 		}
-		if err := QualifyDuplicates(d.Tables); err != nil {
+		if err := QualifyTables(d.Tables); err != nil {
+			return nil, err
+		}
+		if err := QualifyViews(d.Views); err != nil {
 			return nil, err
 		}
 		if err := QualifyReferences(d.Tables, s); err != nil {
@@ -58,24 +73,46 @@ func Marshal(v any, marshaler schemahcl.Marshaler, schemaSpec func(schem *schema
 	return marshaler.MarshalSpec(d)
 }
 
-// QualifyDuplicates sets the Qualified field equal to the schema name in any tables
-// with duplicate names in the provided table specs.
-func QualifyDuplicates(tableSpecs []*sqlspec.Table) error {
-	seen := make(map[string]*sqlspec.Table, len(tableSpecs))
-	for _, tbl := range tableSpecs {
-		if s, ok := seen[tbl.Name]; ok {
+// QualifyTables sets the Qualifier field equal to the schema
+// name in any tables with duplicate names in the provided specs.
+func QualifyTables(specs []*sqlspec.Table) error {
+	seen := make(map[string]*sqlspec.Table, len(specs))
+	for _, t := range specs {
+		if s, ok := seen[t.Name]; ok {
 			schemaName, err := SchemaName(s.Schema)
 			if err != nil {
 				return err
 			}
 			s.Qualifier = schemaName
-			schemaName, err = SchemaName(tbl.Schema)
+			schemaName, err = SchemaName(t.Schema)
 			if err != nil {
 				return err
 			}
-			tbl.Qualifier = schemaName
+			t.Qualifier = schemaName
 		}
-		seen[tbl.Name] = tbl
+		seen[t.Name] = t
+	}
+	return nil
+}
+
+// QualifyViews sets the Qualifier field equal to the schema
+// name in any tables with duplicate names in the provided specs.
+func QualifyViews(specs []*sqlspec.View) error {
+	seen := make(map[string]*sqlspec.View, len(specs))
+	for _, v := range specs {
+		if s, ok := seen[v.Name]; ok {
+			schemaName, err := SchemaName(s.Schema)
+			if err != nil {
+				return err
+			}
+			s.Qualifier = schemaName
+			schemaName, err = SchemaName(v.Schema)
+			if err != nil {
+				return err
+			}
+			v.Qualifier = schemaName
+		}
+		seen[v.Name] = v
 	}
 	return nil
 }
