@@ -17,7 +17,7 @@ import (
 )
 
 // A diff provides a MySQL implementation for schema.Inspector.
-type inspect struct{ conn }
+type inspect struct{ *conn }
 
 var _ schema.Inspector = (*inspect)(nil)
 
@@ -31,13 +31,20 @@ func (i *inspect) InspectRealm(ctx context.Context, opts *schema.InspectRealmOpt
 		opts = &schema.InspectRealmOption{}
 	}
 	r := schema.NewRealm(schemas...).SetCharset(i.charset).SetCollation(i.collate)
-	if len(schemas) == 0 || !sqlx.ModeInspectRealm(opts).Is(schema.InspectTables) {
-		return r, nil
+	if len(schemas) > 0 {
+		mode := sqlx.ModeInspectRealm(opts)
+		if mode.Is(schema.InspectTables) {
+			if err := i.inspectTables(ctx, r, nil); err != nil {
+				return nil, err
+			}
+			sqlx.LinkSchemaTables(schemas)
+		}
+		if mode.Is(schema.InspectViews) {
+			if err := i.inspectViews(ctx, r, nil); err != nil {
+				return nil, err
+			}
+		}
 	}
-	if err := i.inspectTables(ctx, r, nil); err != nil {
-		return nil, err
-	}
-	sqlx.LinkSchemaTables(schemas)
 	return sqlx.ExcludeRealm(r, opts.Exclude)
 }
 
@@ -64,6 +71,11 @@ func (i *inspect) InspectSchema(ctx context.Context, name string, opts *schema.I
 		}
 		sqlx.LinkSchemaTables(schemas)
 	}
+	if sqlx.ModeInspectSchema(opts).Is(schema.InspectViews) {
+		if err := i.inspectViews(ctx, r, opts); err != nil {
+			return nil, err
+		}
+	}
 	return sqlx.ExcludeSchema(r.Schemas[0], opts.Exclude)
 }
 
@@ -345,20 +357,16 @@ func (i *inspect) addIndexes(s *schema.Schema, rows *sql.Rows) error {
 		}
 		idx, ok := t.Index(name)
 		if !ok {
-			idx = &schema.Index{
-				Name:   name,
-				Unique: !nonuniq.Bool,
-				Table:  t,
-				Attrs: []schema.Attr{
-					&IndexType{T: indexType},
-				},
+			idx = schema.NewIndex(name).
+				SetUnique(!nonuniq.Bool).
+				AddAttrs(&IndexType{T: indexType})
+			if indexType == IndexTypeFullText {
+				putShow(t).addFullText(idx)
 			}
 			if sqlx.ValidString(comment) {
-				idx.Attrs = append(t.Attrs, &schema.Comment{
-					Text: comment.String,
-				})
+				idx.SetComment(comment.String)
 			}
-			t.Indexes = append(t.Indexes, idx)
+			t.AddIndexes(idx)
 		}
 		// Rows are ordered by SEQ_IN_INDEX that specifies the
 		// position of the column in the index definition.
@@ -520,10 +528,12 @@ func (i *inspect) showCreate(ctx context.Context, s *schema.Schema) error {
 		if !ok {
 			continue
 		}
-		if err := i.createStmt(ctx, t); err != nil {
+		c, err := i.createStmt(ctx, t)
+		if err != nil {
 			return err
 		}
-		if err := i.setAutoInc(st, t); err != nil {
+		st.setIndexParser(c)
+		if err := st.setAutoInc(t, c); err != nil {
 			return err
 		}
 	}
@@ -532,44 +542,19 @@ func (i *inspect) showCreate(ctx context.Context, s *schema.Schema) error {
 
 var reAutoinc = regexp.MustCompile(`(?i)\s*AUTO_INCREMENT\s*=\s*(\d+)\s*`)
 
-// setAutoInc extracts the updated AUTO_INCREMENT from CREATE TABLE.
-func (i *inspect) setAutoInc(s *showTable, t *schema.Table) error {
-	if s.auto == nil {
-		return nil
-	}
-	var c CreateStmt
-	if !sqlx.Has(t.Attrs, &c) {
-		return fmt.Errorf("missing CREATE TABLE statement in attributes for %q", t.Name)
-	}
-	if sqlx.Has(t.Attrs, &AutoIncrement{}) {
-		return fmt.Errorf("unexpected AUTO_INCREMENT attributes for table: %q", t.Name)
-	}
-	matches := reAutoinc.FindStringSubmatch(c.S)
-	if len(matches) != 2 {
-		return nil
-	}
-	v, err := strconv.ParseInt(matches[1], 10, 64)
-	if err != nil {
-		return err
-	}
-	s.auto.V = v
-	t.Attrs = append(t.Attrs, s.auto)
-	return nil
-}
-
 // createStmt loads the CREATE TABLE statement for the table.
-func (i *inspect) createStmt(ctx context.Context, t *schema.Table) error {
+func (i *inspect) createStmt(ctx context.Context, t *schema.Table) (*CreateStmt, error) {
 	c := &CreateStmt{}
-	b := &sqlx.Builder{QuoteChar: '`'}
+	b := &sqlx.Builder{QuoteOpening: '`', QuoteClosing: '`'}
 	rows, err := i.QueryContext(ctx, b.P("SHOW CREATE TABLE").Table(t).String())
 	if err != nil {
-		return fmt.Errorf("query CREATE TABLE %q: %w", t.Name, err)
+		return nil, fmt.Errorf("query CREATE TABLE %q: %w", t.Name, err)
 	}
 	if err := sqlx.ScanOne(rows, &sql.NullString{}, &c.S); err != nil {
-		return fmt.Errorf("scan CREATE TABLE %q: %w", t.Name, err)
+		return nil, fmt.Errorf("scan CREATE TABLE %q: %w", t.Name, err)
 	}
 	t.Attrs = append(t.Attrs, c)
-	return nil
+	return c, nil
 }
 
 var reCurrTimestamp = regexp.MustCompile(`(?i)^current_timestamp(?:\(\d?\))?$`)
@@ -672,7 +657,11 @@ func (i *inspect) marDefaultExpr(c *schema.Column, x string) schema.Expr {
 }
 
 func (i *inspect) querySchema(ctx context.Context, query string, s *schema.Schema) (*sql.Rows, error) {
-	args := []any{s.Name}
+	// Number of times the schema name is parameterized.
+	args := make([]any, strings.Count(query, "?"))
+	for i := range args {
+		args[i] = s.Name
+	}
 	for _, t := range s.Tables {
 		args = append(args, t.Name)
 	}
@@ -721,8 +710,7 @@ WHERE
 	TABLE_SCHEMA IN (%s)
 	AND TABLE_TYPE = 'BASE TABLE'
 ORDER BY
-	TABLE_SCHEMA, TABLE_NAME
-`
+	TABLE_SCHEMA, TABLE_NAME`
 
 	tablesQueryArgs = `
 SELECT
@@ -746,8 +734,7 @@ WHERE
 	AND TABLE_NAME IN (%s)
 	AND TABLE_TYPE = 'BASE TABLE'
 ORDER BY
-	TABLE_SCHEMA, TABLE_NAME
-`
+	TABLE_SCHEMA, TABLE_NAME`
 
 	// Query to list table check constraints.
 	myChecksQuery  = `SELECT t1.TABLE_NAME, t1.CONSTRAINT_NAME, t2.CHECK_CLAUSE, t1.ENFORCED` + checksQuery
@@ -763,8 +750,7 @@ WHERE
 	AND t1.TABLE_SCHEMA = ?
 	AND t1.TABLE_NAME IN (%s)
 ORDER BY
-	t1.CONSTRAINT_NAME
-`
+	t1.CONSTRAINT_NAME`
 
 	// Query to list table foreign keys.
 	fksQuery = `
@@ -776,22 +762,20 @@ SELECT
 	t1.REFERENCED_TABLE_NAME,
 	t1.REFERENCED_COLUMN_NAME,
 	t1.REFERENCED_TABLE_SCHEMA,
-	t3.UPDATE_RULE,
-	t3.DELETE_RULE
+	t2.UPDATE_RULE,
+	t2.DELETE_RULE
 FROM
 	INFORMATION_SCHEMA.KEY_COLUMN_USAGE AS t1
-	JOIN INFORMATION_SCHEMA.TABLE_CONSTRAINTS AS t2
-	JOIN INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS AS t3
+	JOIN INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS AS t2
 	ON t1.CONSTRAINT_NAME = t2.CONSTRAINT_NAME
-	AND t1.CONSTRAINT_NAME = t3.CONSTRAINT_NAME
-	AND t1.TABLE_SCHEMA = t2.TABLE_SCHEMA
-	AND t1.TABLE_SCHEMA = t3.CONSTRAINT_SCHEMA
 WHERE
-	t2.CONSTRAINT_TYPE = 'FOREIGN KEY'
-	AND t1.TABLE_SCHEMA = ?
+	t1.REFERENCED_COLUMN_NAME IS NOT NULL
+	AND BINARY t1.TABLE_SCHEMA = ?
+	AND BINARY t2.CONSTRAINT_SCHEMA = ?
 	AND t1.TABLE_NAME IN (%s)
 ORDER BY
-	t1.CONSTRAINT_NAME,
+	BINARY t1.TABLE_NAME,
+	BINARY t1.CONSTRAINT_NAME,
 	t1.ORDINAL_POSITION`
 )
 
@@ -859,6 +843,13 @@ type (
 		T string // BTREE, HASH, FULLTEXT, SPATIAL, RTREE
 	}
 
+	// IndexParser defines the parser plugin used
+	// by a FULLTEXT index.
+	IndexParser struct {
+		schema.Attr
+		P string // Name of the parser plugin. e.g., ngram or mecab.
+	}
+
 	// BitType represents the type bit.
 	BitType struct {
 		schema.Type
@@ -877,11 +868,72 @@ type (
 	// required and for what.
 	showTable struct {
 		schema.Attr
-		// AUTO_INCREMENT value to due missing value in information_schema.
+		// AUTO_INCREMENT value due to missing value in information_schema.
 		auto *AutoIncrement
+		// FULLTEXT indexes that might have custom parser.
+		idxs []*schema.Index
 	}
 )
 
+// addIndex adds an index to the list of indexes
+// that needs further processing.
+func (s *showTable) addFullText(idx *schema.Index) {
+	s.idxs = append(s.idxs, idx)
+}
+
+// setAutoInc extracts the updated AUTO_INCREMENT from CREATE TABLE.
+func (s *showTable) setAutoInc(t *schema.Table, c *CreateStmt) error {
+	if s.auto == nil {
+		return nil
+	}
+	if sqlx.Has(t.Attrs, &AutoIncrement{}) {
+		return fmt.Errorf("unexpected AUTO_INCREMENT attributes for table: %q", t.Name)
+	}
+	matches := reAutoinc.FindStringSubmatch(c.S)
+	if len(matches) != 2 {
+		return nil
+	}
+	v, err := strconv.ParseInt(matches[1], 10, 64)
+	if err != nil {
+		return err
+	}
+	s.auto.V = v
+	t.Attrs = append(t.Attrs, s.auto)
+	return nil
+}
+
+// reIndexParser matches the parser name from the index definition.
+var reIndexParser = regexp.MustCompile("/\\*!50100 WITH PARSER `([^`]+)` \\*/")
+
+// setIndexParser updates the FULLTEXT parser from CREATE TABLE statement.
+func (s *showTable) setIndexParser(c *CreateStmt) {
+	b := (&sqlx.Builder{QuoteOpening: '`', QuoteClosing: '`'}).P("FULLTEXT KEY")
+	for _, idx := range s.idxs {
+		bi := b.Clone().Ident(idx.Name).Wrap(func(b *sqlx.Builder) {
+			b.MapComma(idx.Parts, func(i int, b *sqlx.Builder) {
+				// We expect column names only, as functional
+				// fulltext indexes are not supported by MySQL.
+				if idx.Parts[i].C != nil {
+					b.Ident(idx.Parts[i].C.Name)
+				}
+			})
+		})
+		i := strings.Index(c.S, bi.String())
+		if i == -1 || i+bi.Len() >= len(c.S) {
+			continue
+		}
+		i += bi.Len()
+		j := strings.Index(c.S[i:], "\n")
+		if j == -1 {
+			continue
+		}
+		// The rest of the line holds index, algorithm and lock options.
+		if matches := reIndexParser.FindStringSubmatch(c.S[i : i+j]); len(matches) == 2 {
+			idx.AddAttrs(&IndexParser{P: matches[1]})
+		}
+	}
+}
+
 func putShow(t *schema.Table) *showTable {
 	for i := range t.Attrs {
 		if s, ok := t.Attrs[i].(*showTable); ok {
