@@ -8,6 +8,7 @@ import (
 	"context"
 	"testing"
 
+	"ariga.io/atlas/sql/internal/sqltest"
 	"ariga.io/atlas/sql/migrate"
 	"ariga.io/atlas/sql/mysql"
 	_ "ariga.io/atlas/sql/mysql/mysqlcheck"
@@ -15,6 +16,7 @@ import (
 	"ariga.io/atlas/sql/sqlcheck"
 	"ariga.io/atlas/sql/sqlclient"
 
+	"github.com/DATA-DOG/go-sqlmock"
 	"github.com/stretchr/testify/require"
 )
 
@@ -24,13 +26,15 @@ func TestDataDepend_MySQL_ImplicitUpdate(t *testing.T) {
 		pass   = &sqlcheck.Pass{
 			Dev: &sqlclient.Client{
 				Name:   "mysql",
-				Driver: &mysql.Driver{},
+				Driver: devDriver(t, "5.7.0"),
 			},
 			File: &sqlcheck.File{
 				File: testFile{name: "1.sql"},
 				Changes: []*sqlcheck.Change{
 					{
-						Stmt: "ALTER TABLE users",
+						Stmt: &migrate.Stmt{
+							Text: "ALTER TABLE users",
+						},
 						Changes: schema.Changes{
 							&schema.ModifyTable{
 								T: schema.NewTable("users").
@@ -60,9 +64,9 @@ func TestDataDepend_MySQL_ImplicitUpdate(t *testing.T) {
 			}),
 		}
 	)
-	az, err := sqlcheck.AnalyzerFor(mysql.DriverName, nil)
+	azs, err := sqlcheck.AnalyzerFor(mysql.DriverName, nil)
 	require.NoError(t, err)
-	require.NoError(t, az.Analyze(context.Background(), pass))
+	require.NoError(t, sqlcheck.Analyzers(azs).Analyze(context.Background(), pass))
 	require.Equal(t, report.Diagnostics[0].Text, `Adding a non-nullable "int" column "b" on table "users" without a default value implicitly sets existing rows with 0`)
 	require.Equal(t, report.Diagnostics[1].Text, `Adding a non-nullable "float" column "c" on table "users" without a default value implicitly sets existing rows with 0`)
 	require.Equal(t, report.Diagnostics[2].Text, `Adding a non-nullable "varchar" column "d" on table "users" without a default value implicitly sets existing rows with ""`)
@@ -71,20 +75,20 @@ func TestDataDepend_MySQL_ImplicitUpdate(t *testing.T) {
 }
 
 func TestDataDepend_MySQL8_ImplicitUpdate(t *testing.T) {
-	drv := &mysql.Driver{}
-	drv.V = "8.0.19"
 	var (
 		report *sqlcheck.Report
 		pass   = &sqlcheck.Pass{
 			Dev: &sqlclient.Client{
 				Name:   "mysql",
-				Driver: drv,
+				Driver: devDriver(t, "8.0.19"),
 			},
 			File: &sqlcheck.File{
 				File: testFile{name: "1.sql"},
 				Changes: []*sqlcheck.Change{
 					{
-						Stmt: "ALTER TABLE users",
+						Stmt: &migrate.Stmt{
+							Text: "ALTER TABLE users",
+						},
 						Changes: schema.Changes{
 							&schema.ModifyTable{
 								T: schema.NewTable("users").
@@ -106,9 +110,9 @@ func TestDataDepend_MySQL8_ImplicitUpdate(t *testing.T) {
 			}),
 		}
 	)
-	az, err := sqlcheck.AnalyzerFor(mysql.DriverName, nil)
+	azs, err := sqlcheck.AnalyzerFor(mysql.DriverName, nil)
 	require.NoError(t, err)
-	require.NoError(t, az.Analyze(context.Background(), pass))
+	require.NoError(t, sqlcheck.Analyzers(azs).Analyze(context.Background(), pass))
 	require.Equal(t,
 		report.Diagnostics[0].Text,
 		`Adding a non-nullable "timestamp" column "b" on table "users" without a default value implicitly sets existing rows with 0000-00-00 00:00:00`,
@@ -122,13 +126,15 @@ func TestDataDepend_MySQL_MightFail(t *testing.T) {
 		pass   = &sqlcheck.Pass{
 			Dev: &sqlclient.Client{
 				Name:   "mysql",
-				Driver: &mysql.Driver{},
+				Driver: devDriver(t, "8.0.19"),
 			},
 			File: &sqlcheck.File{
 				File: testFile{name: "1.sql"},
 				Changes: []*sqlcheck.Change{
 					{
-						Stmt: "ALTER TABLE users",
+						Stmt: &migrate.Stmt{
+							Text: "ALTER TABLE users",
+						},
 						Changes: schema.Changes{
 							&schema.ModifyTable{
 								T: schema.NewTable("users").
@@ -154,29 +160,29 @@ func TestDataDepend_MySQL_MightFail(t *testing.T) {
 			}),
 		}
 	)
-	az, err := sqlcheck.AnalyzerFor(mysql.DriverName, nil)
+	azs, err := sqlcheck.AnalyzerFor(mysql.DriverName, nil)
 	require.NoError(t, err)
-	require.NoError(t, az.Analyze(context.Background(), pass))
+	require.NoError(t, sqlcheck.Analyzers(azs).Analyze(context.Background(), pass))
 	require.Equal(t, report.Diagnostics[0].Text, `Adding a non-nullable "date" column "b" will fail in case table "users" is not empty`)
 	require.Equal(t, report.Diagnostics[1].Text, `Adding a non-nullable "datetime" column "c" will fail in case table "users" is not empty`)
 	require.Equal(t, report.Diagnostics[2].Text, `Adding a non-nullable "point" column "d" will fail in case table "users" is not empty`)
 }
 
 func TestDataDepend_Maria_ImplicitUpdate(t *testing.T) {
-	drv := &mysql.Driver{}
-	drv.V = "10.7.1-MariaDB"
 	var (
 		report *sqlcheck.Report
 		pass   = &sqlcheck.Pass{
 			Dev: &sqlclient.Client{
 				Name:   "mysql",
-				Driver: drv,
+				Driver: devDriver(t, "10.7.1-MariaDB"),
 			},
 			File: &sqlcheck.File{
 				File: testFile{name: "1.sql"},
 				Changes: []*sqlcheck.Change{
 					{
-						Stmt: "ALTER TABLE users",
+						Stmt: &migrate.Stmt{
+							Text: "ALTER TABLE users",
+						},
 						Changes: schema.Changes{
 							&schema.ModifyTable{
 								T: schema.NewTable("users").
@@ -210,9 +216,9 @@ func TestDataDepend_Maria_ImplicitUpdate(t *testing.T) {
 			}),
 		}
 	)
-	az, err := sqlcheck.AnalyzerFor(mysql.DriverName, nil)
+	azs, err := sqlcheck.AnalyzerFor(mysql.DriverName, nil)
 	require.NoError(t, err)
-	require.NoError(t, az.Analyze(context.Background(), pass))
+	require.NoError(t, sqlcheck.Analyzers(azs).Analyze(context.Background(), pass))
 	require.Equal(t, report.Diagnostics[0].Text, `Adding a non-nullable "text" column "b" on table "users" without a default value implicitly sets existing rows with ""`)
 	require.Equal(t, report.Diagnostics[1].Text, `Adding a non-nullable "json" column "c" on table "users" without a default value implicitly sets existing rows with ""`)
 	require.Equal(t, report.Diagnostics[2].Text, `Adding a non-nullable "date" column "d" on table "users" without a default value implicitly sets existing rows with 00:00:00`)
@@ -231,3 +237,19 @@ type testFile struct {
 func (t testFile) Name() string {
 	return t.name
 }
+
+func devDriver(t *testing.T, version string) migrate.Driver {
+	db, mk, err := sqlmock.New()
+	require.NoError(t, err)
+	mk.ExpectQuery("SELECT @@version, @@collation_server, @@character_set_server, @@lower_case_table_name").
+		WillReturnRows(sqltest.Rows(`
++-----------------+--------------------+------------------------+--------------------------+ 
+| @@version       | @@collation_server | @@character_set_server | @@lower_case_table_names | 
++-----------------+--------------------+------------------------+--------------------------+ 
+|` + version + `  | utf8_general_ci    | utf8                   | 0                        | 
++-----------------+--------------------+------------------------+--------------------------+ 
+`))
+	drv, err := mysql.Open(db)
+	require.NoError(t, err)
+	return drv
+}
