@@ -104,9 +104,7 @@ table "accounts" {
 	err := EvalHCLBytes([]byte(f), &s, nil)
 	require.NoError(t, err)
 
-	exp := &schema.Schema{
-		Name: "schema",
-	}
+	exp := schema.NewRealm(schema.New("schema")).Schemas[0]
 	exp.Tables = []*schema.Table{
 		{
 			Name:   "table",
@@ -266,6 +264,63 @@ table "accounts" {
 	require.EqualValues(t, exp, &s)
 }
 
+func TestUnmarshalViews(t *testing.T) {
+	f := `table "t1" {
+  schema = schema.public
+  column "id" {
+    null = false
+    type = int
+  }
+}
+view "v1" {
+ schema = schema.public
+ as     = "SELECT * FROM t2 WHERE id IS NOT NULL"
+}
+view "v2" {
+  schema = schema.public
+  column "id" {
+    null = false
+    type = int
+  }
+  as      = "SELECT * FROM t3 WHERE id IS NOT NULL ORDER BY id"
+  comment = "view comment"
+}
+view "v3" {
+  schema     = schema.public
+  as         = "SELECT * FROM v2 JOIN t1 USING (id)"
+  depends_on = [view.v1, table.t1]
+}
+schema "public" {
+}
+`
+	var (
+		r   schema.Realm
+		s   schema.Schema
+		exp = schema.New("public").
+			AddTables(
+				schema.NewTable("t1").
+					AddColumns(
+						schema.NewIntColumn("id", "int"),
+					),
+			).
+			AddViews(
+				schema.NewView("v1", "SELECT * FROM t2 WHERE id IS NOT NULL"),
+				schema.NewView("v2", "SELECT * FROM t3 WHERE id IS NOT NULL ORDER BY id").
+					AddColumns(
+						schema.NewIntColumn("id", "int"),
+					).
+					SetComment("view comment"),
+			)
+	)
+	exp.AddViews(
+		schema.NewView("v3", "SELECT * FROM v2 JOIN t1 USING (id)").
+			AddDeps(exp.Views[0], exp.Tables[0]),
+	)
+	r.AddSchemas(exp)
+	require.NoError(t, EvalHCLBytes([]byte(f), &s, nil))
+	require.EqualValues(t, exp, &s)
+}
+
 func TestMarshalSpec_Charset(t *testing.T) {
 	s := &schema.Schema{
 		Name: "test",
@@ -688,6 +743,101 @@ table "users" {
 				),
 		)
 	exp.Tables[0].Columns[0].Indexes = nil
+	schema.NewRealm(exp)
+	require.EqualValues(t, exp, &s)
+}
+
+func TestMarshalSpec_IndexParser(t *testing.T) {
+	s := schema.New("test").
+		AddTables(
+			schema.NewTable("users").
+				AddColumns(
+					schema.NewStringColumn("id", "text"),
+				).
+				AddIndexes(
+					schema.NewIndex("idx1").
+						AddColumns(
+							schema.NewStringColumn("id", "text"),
+						).
+						AddAttrs(&IndexType{T: IndexTypeFullText}, &IndexParser{P: IndexParserNGram}),
+					schema.NewIndex("idx2").
+						AddColumns(
+							schema.NewStringColumn("id", "text"),
+						).
+						AddAttrs(&IndexType{T: IndexTypeFullText}, &IndexParser{P: "custom"}),
+				),
+		)
+	s.Tables[0].SetPrimaryKey(
+		schema.NewPrimaryKey(s.Tables[0].Columns...).
+			AddAttrs(&IndexType{T: IndexTypeHash}),
+	)
+	buf, err := MarshalHCL(s)
+	require.NoError(t, err)
+	require.Equal(t, `table "users" {
+  schema = schema.test
+  column "id" {
+    null = false
+    type = text
+  }
+  primary_key {
+    columns = [column.id]
+    type    = HASH
+  }
+  index "idx1" {
+    columns = [column.id]
+    type    = FULLTEXT
+    parser  = ngram
+  }
+  index "idx2" {
+    columns = [column.id]
+    type    = FULLTEXT
+    parser  = "custom"
+  }
+}
+schema "test" {
+}
+`, string(buf))
+}
+
+func TestUnmarshalSpec_IndexParser(t *testing.T) {
+	var s schema.Schema
+	err := EvalHCLBytes([]byte(`table "users" {
+  schema = schema.test
+  column "id" {
+    null = false
+    type = text
+  }
+  index "idx1" {
+    columns = [column.id]
+    type    = FULLTEXT
+    parser  = ngram
+  }
+  index "idx2" {
+    columns = [column.id]
+    type    = FULLTEXT
+    parser  = "custom"
+  }
+}
+schema "test" {
+}`), &s, nil)
+	require.NoError(t, err)
+	c := schema.NewStringColumn("id", "text")
+	exp := schema.New("test").
+		AddTables(
+			schema.NewTable("users").
+				AddColumns(c).
+				AddIndexes(
+					schema.NewIndex("idx1").
+						AddColumns(c).
+						AddAttrs(&IndexType{T: IndexTypeFullText}, &IndexParser{P: IndexParserNGram}),
+					schema.NewIndex("idx2").
+						AddColumns(c).
+						AddAttrs(&IndexType{T: IndexTypeFullText}, &IndexParser{P: "custom"}),
+
+				),
+		)
+	c.Indexes = nil
+	schema.NewRealm(exp)
 	require.EqualValues(t, exp, &s)
 }
 
@@ -755,6 +905,7 @@ schema "test" {
 		Parts: []*schema.IndexPart{{C: exp.Tables[0].Columns[0]}},
 		Attrs: []schema.Attr{&IndexType{T: IndexTypeHash}},
 	})
+	schema.NewRealm(exp)
 	require.EqualValues(t, exp, &s)
 }
 
@@ -1001,6 +1152,7 @@ table "users" {
 					schema.NewIntColumn("c4", "int").SetGeneratedExpr(&schema.GeneratedExpr{Expr: "c3 * 2", Type: "STORED"}),
 				),
 		)
+	schema.NewRealm(exp)
 	require.EqualValues(t, exp, &s)
 }
 
